from sasktran2 import pysasktran2 as skinternal
import abc
import numpy as np


class GeometryBase(abc.ABC):
    @abc.abstractmethod
    def internal_geometry(self) -> skinternal.Geometry:
        pass

    @abc.abstractmethod
    def num_grid_points(self) -> int:
        pass


class Geometry(GeometryBase):
    def __init__(self, geometry: skinternal.Geometry):
        self._geometry = geometry

    def internal_geometry(self) -> skinternal.Geometry:
        return self._geometry

    def num_grid_points(self) -> int:
        return self._geometry.num_grid_points()


class Geometry1D(Geometry):
    def __init__(self,
                 cos_sza: float,
                 saa: float,
                 earth_radius: float,
                 alt_grid: np.array):
        internal_geometry = skinternal.Geometry(cos_sza, saa, earth_radius, alt_grid)

        super().__init__(internal_geometry)
